@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: atoms.h,v 1.5 1999/02/25 00:33:03 nisse Exp $ */
+ * $Id: atoms.h,v 1.6 2000/04/23 17:48:44 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -31,6 +31,6 @@
 
 UINT32 get_atom_length(int atom);
 const UINT8 *get_atom_name(int atom);
-UINT32 lookup_atom(UINT32 length, UINT8 *name);
+UINT32 lookup_atom(UINT32 length, const UINT8 *name);
 
 #endif /* LSH_ATOMS_H_INCLUDED */
