@@ -1,6 +1,6 @@
 /* exception.h
  *
- * $Id: exception.h,v 1.18 2000/05/28 00:06:46 nisse Exp $ */
+ * $Id: exception.h,v 1.19 2000/06/10 13:14:14 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -140,6 +140,9 @@ void exception_raise(struct exception_handler *e,
 /* Unexpected or unsupported expression type */
 #define EXC_SPKI_TYPE 0x80001
 
+/* Application specific exceptions */
+#define EXC_APP 0x100000
+
 #define EXC_ALL (~0)
 
 extern struct exception_handler default_exception_handler;
