@@ -5,7 +5,7 @@
  * extract the public key, encrypt the private key, and save the
  * results in two separate files.
  *
- * $Id: lsh_keygen.c,v 1.20 2000/05/01 19:50:46 nisse Exp $ */
+ * $Id: lsh_keygen.c,v 1.21 2000/06/01 13:18:07 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -106,11 +106,6 @@ main_argp_parser(int key, char *arg UNUSED, struct argp_state *state)
       state->child_inputs[0] = &self->style;
       state->child_inputs[1] = NULL;
       break;
-#if 0
-    case ARGP_KEY_ARG:
-      argp_error(state, "Spurious arguments.");
-      break;
-#endif
     case 'l':
 	{
 	  char *end;
