@@ -2,7 +2,7 @@
  *
  * Reads a (private) key on stdin, and saves it a private and a public file.
  *
- * $Id: lsh_writekey.c,v 1.20 2000/05/06 19:21:39 nisse Exp $ */
+ * $Id: lsh_writekey.c,v 1.21 2000/05/28 14:10:35 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -24,12 +24,11 @@
  */
 
 #include "algorithms.h"
-#include "blocking_write.h"
-/* For read_password() */
-#include "password.h"
 #include "crypto.h"
 #include "format.h"
 #include "io_commands.h"
+/* For read_password() */
+#include "password.h"
 #include "sexp_commands.h"
 #include "spki_commands.h"
 #include "version.h"
@@ -55,16 +54,6 @@ static struct read_sexp_command read_sexp
 
 #define READ_SEXP (&read_sexp.super.super)
 
-#if 0
-static struct sexp_print_command write_canonical
-= STATIC_PRINT_SEXP(SEXP_CANONICAL);
-#define CANONICAL (&write_canonical.super.super.super)
-
-static struct sexp_print_command write_transport
-= STATIC_PRINT_SEXP(SEXP_TRANSPORT);
-#define TRANSPORT (&write_transport.super.super.super)
-#endif
-
 struct lsh_writekey_options;
 
 extern struct command_simple lsh_writekey_print_public;
@@ -151,7 +140,7 @@ main_options[] =
   { "iteration-count", 'i', "PKCS#5 iteration count", 0, "Default is 1500", 0 },
   { "crypto", 'c', "Algorithm", 0, "Encryption algorithm for the private key file.", 0 },
   { "label", 'l', "Text", 0, "Unencrypted label for the key.", 0 },
-  { "pass phrase", 'p', "Password", 0, NULL, 0 },
+  { "passphrase", 'p', "Password", 0, NULL, 0 },
   { NULL, 0, NULL, 0, NULL, 0 }
 };
 
@@ -250,7 +239,9 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
       break;
       
     case 'o':
+#if 0
     case 'f':
+#endif
       self->file = format_cstring(arg);
       break;
 
