@@ -2,7 +2,7 @@
  *
  * main server program.
  *
- * $Id: lshd.c,v 1.90 2000/05/28 14:14:41 nisse Exp $ */
+ * $Id: lshd.c,v 1.94 2000/06/01 17:30:28 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -47,6 +47,7 @@
 #include "sexp.h"
 #include "sexp_commands.h"
 #include "spki_commands.h"
+#include "srp.h"
 #include "ssh.h"
 #include "tcpforward.h"
 #include "tcpforward_commands.h"
@@ -333,11 +334,6 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
       state->child_inputs[1] = &self->super;
       state->child_inputs[2] = NULL;
       break;
-#if 0
-    case ARGP_KEY_ARG:
-      argp_error(state, "Spurious arguments.");
-      break;
-#endif  
     case ARGP_KEY_END:
       {
 	struct user_db *db = NULL;
@@ -347,7 +343,6 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	  
 	if (self->with_dh_keyexchange || self->with_srp_keyexchange)
 	  {
-	    struct dh_method *dh = make_dh1(self->random);
 	    int i = 0;
 	    self->kex_algorithms 
 	      = alloc_int_list(self->with_dh_keyexchange + self->with_srp_keyexchange);
@@ -357,16 +352,16 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 		LIST(self->kex_algorithms)[i++] = ATOM_DIFFIE_HELLMAN_GROUP1_SHA1;
 		ALIST_SET(self->super.algorithms,
 			  ATOM_DIFFIE_HELLMAN_GROUP1_SHA1,
-			  make_dh_server(dh));
+			  make_dh_server(make_dh1(self->random)));
 	      }
 #if WITH_SRP	    
 	    if (self->with_srp_keyexchange)
 	      {
 		assert(db);
-		LIST(self->kex_algorithms)[i++] = ATOM_SRP_GROUP1_SHA1;
+		LIST(self->kex_algorithms)[i++] = ATOM_SRP_RING1_SHA1;
 		ALIST_SET(self->super.algorithms,
-			  ATOM_SRP_GROUP1_SHA1,
-			  make_srp_server(dh, db));
+			  ATOM_SRP_RING1_SHA1,
+			  make_srp_server(make_srp1(self->random), db));
 	      }
 #endif /* WITH_SRP */
 	    
@@ -554,30 +549,21 @@ main_argp =
 			    (log_peer (listen (options2local options))))))))
 */
 
-/* Invoked when the client requests the userauth service. */
-/* GABA:
-   (expr
-     (name lshd_services)
-     (params 
-       (userauth object command))
-     (expr
-       (lambda (connection)
-         ((userauth connection) connection))))
-*/
 
 /* Invoked when starting the ssh-connection service */
 /* GABA:
    (expr
      (name lshd_connection_service)
      (params
-       (login object command)     
        (hooks object object_list))
      (expr
-       (lambda (user connection)
-         ((progn hooks) (login user
-	                       ; We have to initialize the connection
-			       ; before logging in.
-	                       (init_connection_service connection))))))
+       (lambda (connection)
+         ((progn hooks)
+	    ; We have to initialize the connection
+	    ; before adding handlers.
+	    (init_connection_service
+	      ; Disconnect if connection->user is NULL
+	      (connection_require_userauth connection)))))))
 */
 
 static void
@@ -664,7 +650,8 @@ int main(int argc, char **argv)
   {
     /* Commands to be invoked on the connection */
     struct object_list *connection_hooks;
-
+    struct command *session_setup;
+    
     /* Supported channel requests */
     struct alist *supported_channel_requests
       = make_alist(2,
@@ -672,11 +659,20 @@ int main(int argc, char **argv)
 		   ATOM_EXEC, make_exec_handler(backend, reaper),
 		   -1);
     
+#if WITH_PTY_SUPPORT
+    if (options->with_pty)
+      ALIST_SET(supported_channel_requests,
+		ATOM_PTY_REQ, &pty_request_handler);
+#endif /* WITH_PTY_SUPPORT */
+
+    session_setup = make_install_fix_channel_open_handler
+      (ATOM_SESSION, make_open_session(supported_channel_requests));
     
 #if WITH_TCP_FORWARD
     if (options->with_tcpip_forward)
       connection_hooks = make_object_list
-	(3,
+	(4,
+	 session_setup,
 	 make_tcpip_forward_hook(backend),
 	 make_install_fix_global_request_handler
 	 (ATOM_CANCEL_TCPIP_FORWARD, &tcpip_cancel_forward),
@@ -684,49 +680,42 @@ int main(int argc, char **argv)
 	 -1);
     else
 #endif
-      connection_hooks = make_object_list(0, -1);
-#if WITH_PTY_SUPPORT
-    if (options->with_pty)
-      ALIST_SET(supported_channel_requests,
-		ATOM_PTY_REQ, make_pty_handler());
-#endif /* WITH_PTY_SUPPORT */
+      connection_hooks
+	= make_object_list (1, session_setup, -1);
     {
       /* FIXME: We should check that we have at least one host key. We
        * should also extract the host-key algorithms for which we have
        * keys, instead of hardcoding ssh-dss below. */
- 
-      struct lsh_object *o = lshd_listen
-	(make_simple_listen(backend, NULL),
-	 make_handshake_info(CONNECTION_SERVER,
-			     "lsh - a free ssh",
-			     NULL,
-			     SSH_MAX_PACKET,
-			     options->random,
-			     options->super.algorithms,
-			     make_simple_kexinit
-			     (options->random,
-			      options->kex_algorithms,
-			      make_int_list(1, ATOM_SSH_DSS, -1),
-			      options->super.crypto_algorithms,
-			      options->super.mac_algorithms,
-			      options->super.compression_algorithms,
-			      make_int_list(0, -1)),
-			     options->sshd1),
-	 make_offer_service
-	 (make_alist
-	  (1, ATOM_SSH_USERAUTH,
-	   lshd_services(make_userauth_service
-			 (options->userauth_methods,
-			  options->userauth_algorithms,
-			  make_alist(1, ATOM_SSH_CONNECTION,
-				     lshd_connection_service
-				     (make_server_connection_service(supported_channel_requests),
-				      connection_hooks),
-				     -1))),
-	   -1)));
-    
-      CAST_SUBTYPE(command, server_listen, o);
-    
+
+      CAST_SUBTYPE(command, connection_service, lshd_connection_service(connection_hooks));
+      CAST_SUBTYPE(command, server_listen, 		   
+		   lshd_listen
+		   (make_simple_listen(backend, NULL),
+		    make_handshake_info(CONNECTION_SERVER,
+					"lsh - a free ssh",
+					NULL,
+					SSH_MAX_PACKET,
+					options->random,
+					options->super.algorithms,
+					make_simple_kexinit
+					(options->random,
+					 options->kex_algorithms,
+					 make_int_list(1, ATOM_SSH_DSS, -1),
+					 options->super.crypto_algorithms,
+					 options->super.mac_algorithms,
+					 options->super.compression_algorithms,
+					 make_int_list(0, -1)),
+					options->sshd1),
+		    make_offer_service
+		    (make_alist
+		     (2, ATOM_SSH_CONNECTION, connection_service,
+		      ATOM_SSH_USERAUTH,
+		      make_userauth_service(options->userauth_methods,
+					    options->userauth_algorithms,
+					    make_alist(1, ATOM_SSH_CONNECTION,
+						       connection_service,-1)),
+		      -1))));
+      
       COMMAND_CALL(server_listen, options,
 		   &discard_continuation,
 		   make_report_exception_handler
