@@ -1,6 +1,6 @@
 /* tcpforward_commands.c
  *
- * $Id: tcpforward_commands.c,v 1.26 2000/05/06 11:12:22 nisse Exp $
+ * $Id: tcpforward_commands.c,v 1.27 2000/06/20 06:57:28 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -76,7 +76,7 @@ static struct catch_report_collect catch_channel_open
 
 #define TCPIP_WINDOW_SIZE 10000
 
-/* NOTE: This command does not do any remembering. */
+/* NOTE: make_tcpip_channel() adds the fd to the channel's resource list. */
 static void
 do_tcpip_connect_io(struct command *ignored UNUSED,
 		    struct lsh_object *x,
@@ -150,15 +150,14 @@ new_tcpip_channel(struct channel_open_command *c,
   struct ssh_channel *channel;
 
   /* NOTE: All accepted fd:s must end up in this function, so it
-   * should be ok to delay the REMEMBER() call until here. */
+   * should be ok to delay the REMEMBER() call until here. It is done
+   * by make_tcpip_channel(). */
 
   debug("tcpforward_commands.c: new_tcpip_channel()\n");
 
   channel = make_tcpip_channel(self->peer->fd, TCPIP_WINDOW_SIZE);
   channel->write = connection->write;
 
-  REMEMBER_RESOURCE(channel->resources, &self->peer->fd->super);
-
   *request = format_channel_open(self->type, local_channel_number,
 				 channel, 
 				 "%S%i%S%i",
