@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: werror.c,v 1.46 2000/06/01 13:18:13 nisse Exp $ */
+ * $Id: werror.c,v 1.47 2000/06/26 20:33:52 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -33,8 +33,8 @@
 #include "xalloc.h"
 
 #include <assert.h>
-/* #include <stdio.h> */
 #include <ctype.h>
+#include <string.h>
 
 #if HAVE_UNISTD_H
 #include <unistd.h>
